##  Provision of the Application
  1. LeanIX hereby grants you a royalty-free, non-exclusive, non-transferable right to access and use the Application in support of your use of the LeanIX products and services. Such right shall terminate in connection with the expiration or the termination of your agreement with LeanIX for the use of such products and services.
